==> ejc-budgetmanage-impl-3.0.0-20220401.121145-44-sources.jar: com/ejianc/business/bedget/vo/SubpackagematerialanalysisVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.business.record.bean.RecordmaterialanalysisEntity;
import com.ejianc.business.record.vo.RecordsubpackagematerialanalysisVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 分包施工图预算材料分析
 * 
 * @author generator
 * 
 */
public class SubpackagematerialanalysisVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    
    private List<SubpackagematerialanalysisdetailVO> subpackagematerialanalysisdetailEntities = new ArrayList<>(); // 分包施工图预算材料分析子表
    private List<RecordsubpackagematerialanalysisVO> recordsubpackagematerialanalysisVOS = new ArrayList<>(); // 分包施工图预算材料分析子表


    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    
     /**
      * 分包施工图预算材料分析子表
      */
    public List<SubpackagematerialanalysisdetailVO> getSubpackagematerialanalysisdetailEntities() {
        return subpackagematerialanalysisdetailEntities;
    }
    /**
      * 分包施工图预算材料分析子表
      */
    public void setSubpackagematerialanalysisdetailEntities(List<SubpackagematerialanalysisdetailVO> subpackagematerialanalysisdetailEntities) {
        this.subpackagematerialanalysisdetailEntities = subpackagematerialanalysisdetailEntities;
    }

    /**
      * 分包施工图预算材料分析变更记录子表
      */
    public List<RecordsubpackagematerialanalysisVO> getRecordsubpackagematerialanalysisVOS() {
        return recordsubpackagematerialanalysisVOS;
    }

    public void setRecordsubpackagematerialanalysisVOS(List<RecordsubpackagematerialanalysisVO> recordsubpackagematerialanalysisVOS) {
        this.recordsubpackagematerialanalysisVOS = recordsubpackagematerialanalysisVOS;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220404.033202-49-sources.jar: com/ejianc/business/bedget/vo/SubpackagematerialanalysisVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;

import com.ejianc.business.record.bean.RecordmaterialanalysisEntity;
import com.ejianc.business.record.vo.RecordsubpackagematerialanalysisVO;
import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;

/**
 * 分包施工图预算材料分析
 * 
 * @author generator
 * 
 */
public class SubpackagematerialanalysisVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目id
    private java.lang.String projectName; // 项目名称
    private java.lang.Long changeId; // 变更单据id
    private java.lang.String changeState; // 变更状态
    private java.lang.Long contractId; // 合同id
    private java.lang.String contractName; // 合同名称
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private java.lang.Double total;//合计数量汇总


    public Double getTotal() {
        return total;
    }

    public void setTotal(Double total) {
        this.total = total;
    }

    private List<SubpackagematerialanalysisdetailVO> subpackagematerialanalysisdetailEntities = new ArrayList<>(); // 分包施工图预算材料分析子表
    private List<RecordsubpackagematerialanalysisVO> recordsubpackagematerialanalysisVOS = new ArrayList<>(); // 分包施工图预算材料分析子表


    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-project")
    public java.lang.Long getProjectId() {
        return projectId;
    }

    /**
     * 项目id
     */
    @ReferDeserialTransfer
    public void setProjectId(java.lang.Long projectId) {
        this.projectId = projectId;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 合同id
     */
    @ReferSerialTransfer(referCode="ejc-zjkj-outcontract")
    public java.lang.Long getContractId() {
        return contractId;
    }

    /**
     * 合同id
     */
    @ReferDeserialTransfer
    public void setContractId(java.lang.Long contractId) {
        this.contractId = contractId;
    }
    /**
     * 合同名称
     */
    public java.lang.String getContractName() {
        return contractName;
    }

    /**
     * 合同名称
     */
    public void setContractName(java.lang.String contractName) {
        this.contractName = contractName;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    
     /**
      * 分包施工图预算材料分析子表
      */
    public List<SubpackagematerialanalysisdetailVO> getSubpackagematerialanalysisdetailEntities() {
        return subpackagematerialanalysisdetailEntities;
    }
    /**
      * 分包施工图预算材料分析子表
      */
    public void setSubpackagematerialanalysisdetailEntities(List<SubpackagematerialanalysisdetailVO> subpackagematerialanalysisdetailEntities) {
        this.subpackagematerialanalysisdetailEntities = subpackagematerialanalysisdetailEntities;
    }

    /**
      * 分包施工图预算材料分析变更记录子表
      */
    public List<RecordsubpackagematerialanalysisVO> getRecordsubpackagematerialanalysisVOS() {
        return recordsubpackagematerialanalysisVOS;
    }

    public void setRecordsubpackagematerialanalysisVOS(List<RecordsubpackagematerialanalysisVO> recordsubpackagematerialanalysisVOS) {
        this.recordsubpackagematerialanalysisVOS = recordsubpackagematerialanalysisVOS;
    }
}
